Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type TridentBackendExpansion
- type TridentBackendInterface
- type TridentBackendsGetter
- type TridentNodeExpansion
- type TridentNodeInterface
- type TridentNodesGetter
- type TridentSnapshotExpansion
- type TridentSnapshotInterface
- type TridentSnapshotsGetter
- type TridentStorageClassExpansion
- type TridentStorageClassInterface
- type TridentStorageClassesGetter
- type TridentTransactionExpansion
- type TridentTransactionInterface
- type TridentTransactionsGetter
- type TridentV1Client
- func (c *TridentV1Client) RESTClient() rest.Interface
- func (c *TridentV1Client) TridentBackends(namespace string) TridentBackendInterface
- func (c *TridentV1Client) TridentNodes(namespace string) TridentNodeInterface
- func (c *TridentV1Client) TridentSnapshots(namespace string) TridentSnapshotInterface
- func (c *TridentV1Client) TridentStorageClasses(namespace string) TridentStorageClassInterface
- func (c *TridentV1Client) TridentTransactions(namespace string) TridentTransactionInterface
- func (c *TridentV1Client) TridentVersions(namespace string) TridentVersionInterface
- func (c *TridentV1Client) TridentVolumes(namespace string) TridentVolumeInterface
- type TridentV1Interface
- type TridentVersionExpansion
- type TridentVersionInterface
- type TridentVersionsGetter
- type TridentVolumeExpansion
- type TridentVolumeInterface
- type TridentVolumesGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TridentBackendExpansion ¶
type TridentBackendExpansion interface{}
type TridentBackendInterface ¶
type TridentBackendInterface interface {
Create(*v1.TridentBackend) (*v1.TridentBackend, error)
Update(*v1.TridentBackend) (*v1.TridentBackend, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentBackend, error)
List(opts metav1.ListOptions) (*v1.TridentBackendList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentBackend, err error)
TridentBackendExpansion
}
TridentBackendInterface has methods to work with TridentBackend resources.
type TridentBackendsGetter ¶
type TridentBackendsGetter interface {
TridentBackends(namespace string) TridentBackendInterface
}
TridentBackendsGetter has a method to return a TridentBackendInterface. A group's client should implement this interface.
type TridentNodeExpansion ¶
type TridentNodeExpansion interface{}
type TridentNodeInterface ¶
type TridentNodeInterface interface {
Create(*v1.TridentNode) (*v1.TridentNode, error)
Update(*v1.TridentNode) (*v1.TridentNode, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentNode, error)
List(opts metav1.ListOptions) (*v1.TridentNodeList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentNode, err error)
TridentNodeExpansion
}
TridentNodeInterface has methods to work with TridentNode resources.
type TridentNodesGetter ¶
type TridentNodesGetter interface {
TridentNodes(namespace string) TridentNodeInterface
}
TridentNodesGetter has a method to return a TridentNodeInterface. A group's client should implement this interface.
type TridentSnapshotExpansion ¶
type TridentSnapshotExpansion interface{}
type TridentSnapshotInterface ¶
type TridentSnapshotInterface interface {
Create(*v1.TridentSnapshot) (*v1.TridentSnapshot, error)
Update(*v1.TridentSnapshot) (*v1.TridentSnapshot, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentSnapshot, error)
List(opts metav1.ListOptions) (*v1.TridentSnapshotList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentSnapshot, err error)
TridentSnapshotExpansion
}
TridentSnapshotInterface has methods to work with TridentSnapshot resources.
type TridentSnapshotsGetter ¶
type TridentSnapshotsGetter interface {
TridentSnapshots(namespace string) TridentSnapshotInterface
}
TridentSnapshotsGetter has a method to return a TridentSnapshotInterface. A group's client should implement this interface.
type TridentStorageClassExpansion ¶
type TridentStorageClassExpansion interface{}
type TridentStorageClassInterface ¶
type TridentStorageClassInterface interface {
Create(*v1.TridentStorageClass) (*v1.TridentStorageClass, error)
Update(*v1.TridentStorageClass) (*v1.TridentStorageClass, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentStorageClass, error)
List(opts metav1.ListOptions) (*v1.TridentStorageClassList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentStorageClass, err error)
TridentStorageClassExpansion
}
TridentStorageClassInterface has methods to work with TridentStorageClass resources.
type TridentStorageClassesGetter ¶
type TridentStorageClassesGetter interface {
TridentStorageClasses(namespace string) TridentStorageClassInterface
}
TridentStorageClassesGetter has a method to return a TridentStorageClassInterface. A group's client should implement this interface.
type TridentTransactionExpansion ¶
type TridentTransactionExpansion interface{}
type TridentTransactionInterface ¶
type TridentTransactionInterface interface {
Create(*v1.TridentTransaction) (*v1.TridentTransaction, error)
Update(*v1.TridentTransaction) (*v1.TridentTransaction, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentTransaction, error)
List(opts metav1.ListOptions) (*v1.TridentTransactionList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentTransaction, err error)
TridentTransactionExpansion
}
TridentTransactionInterface has methods to work with TridentTransaction resources.
type TridentTransactionsGetter ¶
type TridentTransactionsGetter interface {
TridentTransactions(namespace string) TridentTransactionInterface
}
TridentTransactionsGetter has a method to return a TridentTransactionInterface. A group's client should implement this interface.
type TridentV1Client ¶
type TridentV1Client struct {
// contains filtered or unexported fields
}
TridentV1Client is used to interact with features provided by the trident.netapp.io group.
func New ¶
func New(c rest.Interface) *TridentV1Client
New creates a new TridentV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*TridentV1Client, error)
NewForConfig creates a new TridentV1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *TridentV1Client
NewForConfigOrDie creates a new TridentV1Client for the given config and panics if there is an error in the config.
func (*TridentV1Client) RESTClient ¶
func (c *TridentV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*TridentV1Client) TridentBackends ¶
func (c *TridentV1Client) TridentBackends(namespace string) TridentBackendInterface
func (*TridentV1Client) TridentNodes ¶
func (c *TridentV1Client) TridentNodes(namespace string) TridentNodeInterface
func (*TridentV1Client) TridentSnapshots ¶
func (c *TridentV1Client) TridentSnapshots(namespace string) TridentSnapshotInterface
func (*TridentV1Client) TridentStorageClasses ¶
func (c *TridentV1Client) TridentStorageClasses(namespace string) TridentStorageClassInterface
func (*TridentV1Client) TridentTransactions ¶
func (c *TridentV1Client) TridentTransactions(namespace string) TridentTransactionInterface
func (*TridentV1Client) TridentVersions ¶
func (c *TridentV1Client) TridentVersions(namespace string) TridentVersionInterface
func (*TridentV1Client) TridentVolumes ¶
func (c *TridentV1Client) TridentVolumes(namespace string) TridentVolumeInterface
type TridentV1Interface ¶
type TridentV1Interface interface {
RESTClient() rest.Interface
TridentBackendsGetter
TridentNodesGetter
TridentSnapshotsGetter
TridentStorageClassesGetter
TridentTransactionsGetter
TridentVersionsGetter
TridentVolumesGetter
}
type TridentVersionExpansion ¶
type TridentVersionExpansion interface{}
type TridentVersionInterface ¶
type TridentVersionInterface interface {
Create(*v1.TridentVersion) (*v1.TridentVersion, error)
Update(*v1.TridentVersion) (*v1.TridentVersion, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentVersion, error)
List(opts metav1.ListOptions) (*v1.TridentVersionList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentVersion, err error)
TridentVersionExpansion
}
TridentVersionInterface has methods to work with TridentVersion resources.
type TridentVersionsGetter ¶
type TridentVersionsGetter interface {
TridentVersions(namespace string) TridentVersionInterface
}
TridentVersionsGetter has a method to return a TridentVersionInterface. A group's client should implement this interface.
type TridentVolumeExpansion ¶
type TridentVolumeExpansion interface{}
type TridentVolumeInterface ¶
type TridentVolumeInterface interface {
Create(*v1.TridentVolume) (*v1.TridentVolume, error)
Update(*v1.TridentVolume) (*v1.TridentVolume, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.TridentVolume, error)
List(opts metav1.ListOptions) (*v1.TridentVolumeList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.TridentVolume, err error)
TridentVolumeExpansion
}
TridentVolumeInterface has methods to work with TridentVolume resources.
type TridentVolumesGetter ¶
type TridentVolumesGetter interface {
TridentVolumes(namespace string) TridentVolumeInterface
}
TridentVolumesGetter has a method to return a TridentVolumeInterface. A group's client should implement this interface.